// StringCreator is used to display a String with a user-specified Font

import java.applet.Applet;
import java.awt.*;
import java.awt.event.*;

public class StringCreator extends Panel implements ItemListener
{
// Private member variables

  private Choice fontNameChoice,
                 fontStyleChoice,
                 fontSizeChoice;

  private TextField stringTextField;
  private Panel choicesPanel;

  private String fontStyleStrings[] = {"Plain", "Bold", "Italic", "Bold & Italic"};

  private int fontStyleInts[] = { Font.PLAIN, Font.BOLD, Font.ITALIC, 
                                  Font.BOLD + Font.ITALIC};

  private int fontSizeInts[] = {8, 10, 12, 14, 16, 18, 20, 24, 30, 36, 48, 72};


// Constructors

  public StringCreator()
  {
    this("");  // As default, put no String.
  }

  public StringCreator(String currentString)
  {
    createComponents();
    addComponents();
    stringTextField.setText( currentString );
    updateTextField();
  }


// public methods

  public String getCurrentString()
  {
    return ( stringTextField.getText() );
  }

  public void setCurrentString(String string)
  {
    stringTextField.setText( string );
  }

  public Font getCurrentFont()
  {
    String fontName = fontNameChoice.getSelectedItem();

    int i = fontStyleChoice.getSelectedIndex(),
        fontStyle = fontStyleInts[i];

    int fontSize = Integer.parseInt( fontSizeChoice.getSelectedItem() );

    return ( new Font( fontName, fontStyle, fontSize ) );
  }


// Private and protected methods

    private void createComponents()
    {
      fontNameChoice = new Choice();
      fontNameChoice.addItemListener(this);
      String fonts[] = Toolkit.getDefaultToolkit().getFontList();
      for (int i = 0; i < fonts.length; i++)
        fontNameChoice.add(fonts[i]);
      fontNameChoice.select(0);

      fontStyleChoice = new Choice();
      fontStyleChoice.addItemListener(this);
      for (int i = 0; i < fontStyleStrings.length; i++) {
        fontStyleChoice.add(fontStyleStrings[i]);
      }
      fontStyleChoice.select(0);

      fontSizeChoice = new Choice();
      fontSizeChoice.addItemListener(this);
      for (int i = 0; i < fontSizeInts.length; i++) {
        fontSizeChoice.add( String.valueOf( fontSizeInts[i] ) );
      }
      fontSizeChoice.select( fontSizeChoice.getItemCount()/3 );

      stringTextField = new TextField();
      stringTextField.setBackground(Color.white);

      choicesPanel = new Panel();
    }

    private void addComponents()
    {
      setLayout(new BorderLayout());
      add(stringTextField, BorderLayout.CENTER);
      add(choicesPanel, BorderLayout.SOUTH);

      choicesPanel.setLayout( new GridLayout(1,3,3,3));
      choicesPanel.add(fontNameChoice);
      choicesPanel.add(fontStyleChoice);
      choicesPanel.add(fontSizeChoice);
    }

  // Event handling method.

    public void itemStateChanged(ItemEvent e)
    {
      updateTextField();
    }

    public void updateTextField()
    {
      stringTextField.setFont( getCurrentFont() );
      stringTextField.validate();
    }

} // end class StringCreator


